Re-exports
pub use alloy_primitives;pub use alloy_primitives::ruint;
Modules
Macros
Structs
- Address
- A wrapper over alloy_primitives::Address that allows us to add custom methods and trait implementations.
- Digest
- Signature
- A wrapper over AlloySignature with custom serialization.
Enums
- Signature
Error - Errors in signature parsing or verification.
Traits
- From
Bool - Allows for the conversion of a boolean to a type This trait is used in tree to properly bound the type of the digest.
- From
U256 - Hashable
- Trait for objects that can be hashed.
Type Aliases
- B256
- 32-byte fixed byte-array type.
- U256
- 256-bit unsigned integer type, consisting of 4, 64-bit limbs.
- U512
- 512-bit unsigned integer type, consisting of 8, 64-bit limbs.